@@ -121,13 +121,9 @@
 #define BOTAN_HAS_AEAD_SIV 20131202
 #define BOTAN_HAS_AES 20131128
 #define BOTAN_HAS_AES_CRYSTALS_XOF 20230816
-#define BOTAN_HAS_AES_VAES 20240803
-#define BOTAN_HAS_AES_VPERM 20190901
 #define BOTAN_HAS_ANSI_X919_MAC 20131128
 #define BOTAN_HAS_ARGON2 20210407
-#define BOTAN_HAS_ARGON2_AVX2 20221216
 #define BOTAN_HAS_ARGON2_FMT 20210407
-#define BOTAN_HAS_ARGON2_SSSE3 20220303
 #define BOTAN_HAS_ARIA 20170415
 #define BOTAN_HAS_ASN1 20201106
 #define BOTAN_HAS_AUTO_RNG 20161126
@@ -153,10 +149,8 @@
 #define BOTAN_HAS_CERTSTOR_SQL 20160818
 #define BOTAN_HAS_CERTSTOR_SYSTEM 20190411
 #define BOTAN_HAS_CHACHA 20180807
-#define BOTAN_HAS_CHACHA_AVX2 20180418
 #define BOTAN_HAS_CHACHA_AVX512 20230101
 #define BOTAN_HAS_CHACHA_RNG 20170728
-#define BOTAN_HAS_CHACHA_SIMD32 20181104
 #define BOTAN_HAS_CIPHER_MODES 20180124
 #define BOTAN_HAS_CIPHER_MODE_PADDING 20131128
 #define BOTAN_HAS_CLASSICMCELIECE 20231023
@@ -216,7 +210,6 @@
 #define BOTAN_HAS_FRODOKEM_AES 20231103
 #define BOTAN_HAS_FRODOKEM_SHAKE 20231114
 #define BOTAN_HAS_GHASH 20201002
-#define BOTAN_HAS_GHASH_CLMUL_VPERM 20201002
 #define BOTAN_HAS_GMAC 20160207
 #define BOTAN_HAS_GOST_28147_89 20131128
 #define BOTAN_HAS_GOST_34_10_2001 20131128
@@ -241,7 +234,6 @@
 #define BOTAN_HAS_KDF_BASE 20131128
 #define BOTAN_HAS_KECCAK 20131128
 #define BOTAN_HAS_KECCAK_PERM 20230613
-#define BOTAN_HAS_KECCAK_PERM_BMI2 20230612
 #define BOTAN_HAS_KEX_TO_KEM_ADAPTER 20240504
 #define BOTAN_HAS_KMAC 20230601
 #define BOTAN_HAS_KUZNYECHIK 20230820
@@ -267,7 +259,6 @@
 #define BOTAN_HAS_MODE_XTS 20131128
 #define BOTAN_HAS_NIST_KEYWRAP 20171119
 #define BOTAN_HAS_NOEKEON 20131128
-#define BOTAN_HAS_NOEKEON_SIMD 20160903
 #define BOTAN_HAS_NUMBERTHEORY 20201108
 #define BOTAN_HAS_OAEP 20250130
 #define BOTAN_HAS_OCSP 20201106
@@ -321,25 +312,13 @@
 #define BOTAN_HAS_SCRYPT 20180902
 #define BOTAN_HAS_SEED 20131128
 #define BOTAN_HAS_SERPENT 20131128
-#define BOTAN_HAS_SERPENT_AVX2 20180824
 #define BOTAN_HAS_SERPENT_AVX512 20230101
-#define BOTAN_HAS_SERPENT_SIMD 20160903
 #define BOTAN_HAS_SHA1 20131128
-#define BOTAN_HAS_SHA1_SIMD_4X32 20250331
-#define BOTAN_HAS_SHA1_X86_SHA_NI 20170518
 #define BOTAN_HAS_SHA2_32 20131128
-#define BOTAN_HAS_SHA2_32_SIMD 20250402
-#define BOTAN_HAS_SHA2_32_X86 20170518
-#define BOTAN_HAS_SHA2_32_X86_AVX2 20250402
 #define BOTAN_HAS_SHA2_64 20131128
 #define BOTAN_HAS_SHA2_64_X86 20250310
-#define BOTAN_HAS_SHA2_64_X86_AVX2 20190117
-#define BOTAN_HAS_SHA2_64_X86_AVX512 20250427
 #define BOTAN_HAS_SHA3 20161018
 #define BOTAN_HAS_SHACAL2 20170813
-#define BOTAN_HAS_SHACAL2_AVX2 20180826
-#define BOTAN_HAS_SHACAL2_SIMD 20170813
-#define BOTAN_HAS_SHACAL2_X86 20170814
 #define BOTAN_HAS_SHAKE 20161009
 #define BOTAN_HAS_SHAKE_CIPHER 20161018
 #define BOTAN_HAS_SHAKE_XOF 20230815
@@ -348,11 +327,7 @@
 #define BOTAN_HAS_SHA_384 20250130
 #define BOTAN_HAS_SHA_512 20250130
 #define BOTAN_HAS_SHA_512_256 20250130
-#define BOTAN_HAS_SIMD_2X64 20250405
-#define BOTAN_HAS_SIMD_4X32 20131128
-#define BOTAN_HAS_SIMD_4X64 20250405
 #define BOTAN_HAS_SIMD_8X64 20250427
-#define BOTAN_HAS_SIMD_AVX2 20180824
 #define BOTAN_HAS_SIMD_AVX512 20230101
 #define BOTAN_HAS_SIPHASH 20150110
 #define BOTAN_HAS_SKEIN_512 20131128
@@ -361,8 +336,6 @@
 #define BOTAN_HAS_SM2 20180801
 #define BOTAN_HAS_SM3 20170402
 #define BOTAN_HAS_SM4 20170716
-#define BOTAN_HAS_SM4_GFNI 20240803
-#define BOTAN_HAS_SM4_X86 20250311
 #define BOTAN_HAS_SOCKETS 20171216
 #define BOTAN_HAS_SODIUM_API 20190615
 #define BOTAN_HAS_SP800_108 20160128
@@ -404,8 +377,6 @@
 #define BOTAN_HAS_XMSS_RFC8391 20201101
 #define BOTAN_HAS_XOF 20230815
 #define BOTAN_HAS_ZFEC 20211211
-#define BOTAN_HAS_ZFEC_SSE2 20211211
-#define BOTAN_HAS_ZFEC_VPERM 20211211
 #define BOTAN_HAS_ZLIB 20160412
 
 
